#!/usr/bin/env python

from I3Tray import *
from os.path import expandvars
import os

inphysfile = "test1-filled.i3"
outrootfile = "tmp.root"
gcsfile = "GCS.i3.gz"

if len(sys.argv) > 1:
	ingcsfile = sys.argv[1]

if len(sys.argv) > 2:
	inphysfile = sys.argv[2]

if len(sys.argv) > 3:
	outrootfile = sys.argv[3]

load("libicetray")
load("libdataclasses")
load("libphys-services")
load("libsim-services")
load("libdataio")
load("libportia")
load("libweighting-module")
load("libophelia")
load("libehe-star")
load("libDomTools")
#load("liblinefit")
#load("libtensor-of-inertia")

tray = I3Tray()


#tray.AddService("I3ReaderServiceFactory","reader")(
#    ("Filename", inphysfile)    
#    )
tray.AddService("I3ReaderServiceFactory","i3reader")(
	("FilenameList",
	 [ingcsfile,inphysfile])
	)

tray.AddModule("I3Muxer", "multiplex")

tray.AddModule("I3HyperReco","hyperreco")(
	("PortiaPulseMapNameATWD", "ATWDPortiaPulse"),
	("PortiaPulseMapNameFADC", "FADCPortiaPulse"),
	("OpheliaFirstGuessTrackName", "OpheliaFirstGuess"),
	("InternalFirstGuess", False),
	#("MinNCh", 80),
	("MinNCh", 1),
	("OutputHyperTrackName", "HyperTrack")
	)

# This module uses the vector<OMKey> of bad DOMs writtent to frame by
# the bad DOM list service see bdmodule above
workspace=os.path.expandvars("$I3_BUILD")
badf = workspace + "/BadDomList/BadDomList.bdlist.80str.nue.txt"
tray.AddModule("I3OMSelection<I3DOMLaunchSeries>","badoms")(
	("BadOMFileName", badf ),
	#("InputOMSelection","BadDomsList"),
	("OutputOMSelection","BadOMSelection"),
	("InputResponse","CleanInIceRawData"),
	("OutputResponse","CleanedInIceRawDataTMP"),
	)

tray.AddModule("I3OpheliaConvertHyperTrack","convert_hyper")(
        ("InputHyperTrackName", "HyperTrack"),
        ("OutputParticleName", "HyperParticle"),
        )

tray.AddModule("I3EheStarLateralModule","star_cobfg")(
        ("useMCtruth",      True),
        ("useRecoParticle", True),
        ("inMCName", "I3MCTree"),
        ("inRecoParticleName", "HyperParticle"),
	("inAtwdPulseName", "ATWDPortiaPulse"),
        ("inFadcPulseName", "FADCPortiaPulse"),
        #("inBadDomListName", "BadOMSelection"),
	
        ("outEheStarLateralMCName", "EheStarLateralMC"),
        ("outEheStarLateralRecoName", "EheStarLateralReco"),
	("npe_fitMin", 5), # defalt = 10                           
	)

tray.AddModule("I3EheStarFirstDomsModule","star_fg")(
	("inPortiaPulseName", "ATWDPortiaPulse"),
	("outEheStarFirstDomsName", "EheStarFirstDoms"),
	)

tray.AddModule("I3WeigherModuleJulietPlus","weight")(
	("doTree",                  True),
	("outTreeName",            "JulietTree"),
	("outFileName",             outrootfile),
	("inMCHitSeriesName",      "MCHitSeriesMap"),
	("inDOMLaunchName",        "CleanInIceRawData"),
	("inMCTreeName",           "I3MCTree"),
	("frameMCWeightName", "JulietWeightDict"),
	
	("doPulseTree",            False),
	("inAtwdPortiaName",       "ATWDPortiaPulse"),
	("inFadcPortiaName",       "FADCPortiaPulse"),
	
	("doMCHitTree",            False),
	("McHitCompressionOption", True),
	
	("doFirstguessTree",       True),
	("inFirstguessName",       "OpheliaFirstGuess"),

	("doHyperRecoTree",       True),
	("inHyperRecoName",       "HyperTrack"),

	("doFillWeight",           False),
	("doReWeigh",              False),
	
	("doEheStarTree",          True),
	("inEheStarLateralMCName",   "EheStarLateralMC"),
	("inEheStarLateralRecoName",   "EheStarLateralReco"),

	)

tray.AddModule("I3Writer","writer")(
	        ("filename", "tmp.i3"),
		("streams",["Physics"]),
		)

tray.AddModule("TrashCan", "bye")

tray.Execute()
tray.Finish()

